# lsst-pipe-base

[![pypi](https://img.shields.io/pypi/v/lsst-pipe-base.svg)](https://pypi.org/project/lsst-pipe-base/)
[![codecov](https://codecov.io/gh/lsst/pipe_base/branch/main/graph/badge.svg?token=nTEA5ZAYiD)](https://codecov.io/gh/lsst/pipe_base)

Pipeline infrastructure code for the [Rubin Science Pipelines](https://pipelines.lsst.io).

* SPIE Paper from 2022: [The Vera C. Rubin Observatory Data Butler and Pipeline Execution System](https://arxiv.org/abs/2206.14941)

PyPI: [lsst-pipe-base](https://pypi.org/project/lsst-pipe-base/)
